@@ -1,19 +1,19 @@
 package Cog::WebApp;
-use Mouse;
+use Mo;
 extends 'Cog::Base';
 
-# use XXX;
-
-has env => ( is => 'rw' );
+has env => ();
 
 use constant index_file => '';
 use constant plugins => [];
 use constant site_navigation => [];
 use constant url_map => [];
 use constant post_map => [];
+use constant coffee_files => [];
 use constant js_files => [qw(
-    jquery-1.4.4.js
-    jquery.json-2.2.js
+    jquery.js
+    jquery-ui.js
+    jquery-json.js
     jquery.cookie.js
     jquery.jemplate.js
     jemplate.js
@@ -23,17 +23,19 @@ use constant js_files => [qw(
     fixups.js
 )];
 use constant css_files => [qw(
+    reset.css
     layout.css
-    page-list.css
-    page-display.css
+    layout-table.css
 )];
 use constant image_files => [];
 use constant template_files => [];
-use constant runner_class => 'Cog::WebApp::Runner';
+use constant runner_class => 'Cog::Runner';
+use constant rewrite => undef;
 
 sub web_app {
     my $self = shift;
-    my $index_file = 'static/index.html';
+    my $webapp = $self->app->webapp_root;
+    my $index_file = "$webapp/index.html";
     open INDEX, $index_file or die "Can't open '$index_file'";
     my $html = do {local $/; <INDEX>};
     close INDEX or die;
@@ -94,11 +96,22 @@ sub handle_post {
     }
 }
 
+sub response_json {
+    my ($self, $data) = @_;
+    die "response_json() requires a hash or array" unless ref $data;
+    my $json = $self->json->encode($data);
+    return [
+        200,
+        [ 'Content-Type' => 'application/json' ],
+        [ $json ],
+    ];
+}
+
 sub read_json {
     my $self = shift;
     my $env = $self->env;
     return unless
-        $env->{CONTENT_TYPE} =~ m!application/json! and
+#         $env->{CONTENT_TYPE} =~ m!application/json! and
         $env->{CONTENT_LENGTH};
     my $json = do { my $io = $env->{'psgi.input'}; local $/; <$io> };
     $env->{post_data} = $self->json->decode($json);
